@@ -6,7 +6,7 @@ use App::clad;
 use Carp ();
 
 # ABSTRACT: Parallel SSH client
-our $VERSION = '0.99_03'; # TRIAL VERSION
+our $VERSION = '0.99_04'; # TRIAL VERSION
 
 
 
@@ -52,7 +52,7 @@ sub run
       ($opts->{n} ? ('-n') : ()),
       ($opts->{l} ? ('-l' => $opts->{l}) : ()),
       ($opts->{a} ? ('-a') : ()),
-      $cluster, '--', @cmd,
+      $cluster, @cmd,
     )->run;
   };
 }
@@ -71,7 +71,7 @@ Clustericious::Admin - Parallel SSH client
 
 =head1 VERSION
 
-version 0.99_03
+version 0.99_04
 
 =head1 SYNOPSIS
 
